summaryrefslogtreecommitdiff
path: root/plugins/Realtime
diff options
context:
space:
mode:
authorEvan Prodromou <evan@status.net>2009-10-13 17:21:41 -0400
committerEvan Prodromou <evan@status.net>2009-10-13 17:21:41 -0400
commit181de862efe2da16164daea32b74c3da8ea2ed7e (patch)
tree8e7ebfc731f7e65f26b3b71d65c28bbe51ac2c85 /plugins/Realtime
parent76ac7c358a3245f4032f49152055cae94c4616ff (diff)
parent659a04b556f75551548c0b2fff633b15cd114135 (diff)
Merge branch '0.9.x' of git@gitorious.org:statusnet/mainline into 0.9.x
Diffstat (limited to 'plugins/Realtime')
-rw-r--r--plugins/Realtime/RealtimePlugin.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/Realtime/RealtimePlugin.php b/plugins/Realtime/RealtimePlugin.php
index 181927968..0c7c1240c 100644
--- a/plugins/Realtime/RealtimePlugin.php
+++ b/plugins/Realtime/RealtimePlugin.php
@@ -240,13 +240,13 @@ class RealtimePlugin extends Plugin
// FIXME: this code should be abstracted to a neutral third
// party, like Notice::asJson(). I'm not sure of the ethics
// of refactoring from within a plugin, so I'm just abusing
- // the TwitterApiAction method. Don't do this unless you're me!
+ // the ApiAction method. Don't do this unless you're me!
- require_once(INSTALLDIR.'/lib/twitterapi.php');
+ require_once(INSTALLDIR.'/lib/api.php');
- $act = new TwitterApiAction('/dev/null');
+ $act = new ApiAction('/dev/null');
- $arr = $act->twitter_status_array($notice, true);
+ $arr = $act->twitterStatusArray($notice, true);
$arr['url'] = $notice->bestUrl();
$arr['html'] = htmlspecialchars($notice->rendered);
$arr['source'] = htmlspecialchars($arr['source']);